==> gnumeric-1.12.13.tar.xz: gnumeric-1.12.13/test/t6511-solver.pl <==
#!/usr/bin/perl -w
# -----------------------------------------------------------------------------

use strict;
use lib ($0 =~ m|^(.*/)| ? $1 : ".");
use GnumericTest;

my $file = "$samples/solver-tests.gnumeric";

&message ("Check solver gnumeric roundtrip.");
&test_roundtrip ($file,
		 'format' => 'Gnumeric_XmlIO:sax',
		 'ext' => "gnm");

if (1) {
    &message ("Not checking solver ods roundtrip -- format is deficient");
} else {
    &message ("Check solver ods roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_OpenCalc:odf',
		     'ext' => "ods",
		     'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'",
		     'ignore_failure' => 1);
}

my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";

if (1) {
    &message ("Not checking solver xls/BIFF7 roundtrip -- format is deficient");
} else {
    &message ("Check solver xls/BIFF7 roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:excel_biff7',
		     'ext' => "xls",
		     'resize' => '16384x256',
		     'filter2' => $xls_codepage_filter,
		     'ignore_failure' => 1);
}

if (1) {
    &message ("Not checking solver xls/BIFF8 roundtrip -- format is deficient");
} else {
    &message ("Check solver xls/BIFF8 roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:excel_biff8',
		     'ext' => "xls",
		     'filter2' => $xls_codepage_filter,
		     'ignore_failure' => 1);
}

if (1) {
    &message ("Not checking solver xlsx roundtrip -- format is deficient");
} else {
    &message ("Check solver xlsx roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:xlsx',
		     'ext' => "xlsx",
		     'resize' => '1048576x16384',
		     'ignore_failure' => 1);
}

==> gnumeric-1.12.15.tar.xz: gnumeric-1.12.15/test/t6511-solver.pl <==
#!/usr/bin/perl -w
# -----------------------------------------------------------------------------

use strict;
use lib ($0 =~ m|^(.*/)| ? $1 : ".");
use GnumericTest;

my $file = "$samples/solver-tests.gnumeric";

&message ("Check solver gnumeric roundtrip.");
&test_roundtrip ($file,
		 'format' => 'Gnumeric_XmlIO:sax',
		 'ext' => "gnm");

if (1) {
    &message ("Not checking solver ods roundtrip -- format is deficient");
} else {
    &message ("Check solver ods roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_OpenCalc:odf',
		     'ext' => "ods",
		     'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
}

my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";

if (1) {
    &message ("Not checking solver xls/BIFF7 roundtrip -- format is deficient");
} else {
    &message ("Check solver xls/BIFF7 roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:excel_biff7',
		     'ext' => "xls",
		     'resize' => '16384x256',
		     'filter2' => $xls_codepage_filter);
}

if (1) {
    &message ("Not checking solver xls/BIFF8 roundtrip -- format is deficient");
} else {
    &message ("Check solver xls/BIFF8 roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:excel_biff8',
		     'ext' => "xls",
		     'filter2' => $xls_codepage_filter);
}

if (1) {
    &message ("Not checking solver xlsx roundtrip -- format is deficient");
} else {
    &message ("Check solver xlsx roundtrip.");
    &test_roundtrip ($file,
		     'format' => 'Gnumeric_Excel:xlsx',
		     'ext' => "xlsx",
		     'resize' => '1048576x16384');
}
